discord-continued
====================

**A simple API wrapper for Discord interactions.**

Forked from [Discord Interactions](https://github.com/goverfl0w/discord-interactions/tree/unstable)

Work in progress